.. memote documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

====================================================
memote - the genome-scale metabolic model test suite
====================================================

.. include:: ../README.rst
   :start-after: summary-start
   :end-before: summary-end

.. include:: ../README.rst
   :start-after: who-start
   :end-before: who-end

Contents
========

.. toctree::
   :maxdepth: 2

   getting_started
   flowchart
   test_suite
   api
   contributing
   authors
   history


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
